

from importlib import reload

#
##
### Utilities to buld commpon LP objects
##
#



# output fluxes calculated from biomass composition
import BiomassComp



def BuildLP(m, fd=None):
    """ build lp from model m using flux dictionary fd """

    if fd==None:
        reload(BiomassComp)
        fd = BiomassComp.FluxDic(m)
    
    lp=m.GetLP()
    lp.SetObjective(m.sm.cnames)   # minimise total flux
    lp.SetFixedFlux(fd)

    return lp
    

def BuildClosedLP(m):

    lp = m.GetLP()
    for tx in m.Transporters(True):
        lp.SetFixedFlux({tx:0})

    return lp


def ATPaseCheckLP(m):
    lp = BuildClosedLP(m)
    lp.SetFixedFlux({"ATPase":1})
    lp.Solve()
    return lp


def NADHCheckLP(m):
    lp = BuildClosedLP(m)
    lp.SetFixedFlux({"NADHOxid":1})
    lp.Solve()
    return lp


def NADPHCheckLP(m):
    lp = BuildClosedLP(m)
    lp.SetFixedFlux({"NADPHOxid":1})
    lp.Solve()
    return lp

def CheckBiomass(m):
    rv = {}
    bmtx = [reac for reac in m.smx.cnames if reac.endswith('bm_tx')]
    lp = m.GetLP()
    lp.SetObjective(m.sm.cnames)
    for reac in bmtx:
        lp.SetFixedFlux({reac:-1})
        lp.Solve()
        sol = lp.GetPrimSol()
        rv[reac] = sol
        lp.ClearFluxConstraint(reac)
    return rv
